@@ -241,6 +241,8 @@ __extras = {
     "CLIENT": "client",
     "CORRUPT": "corrupt_connection",
     "DECRYPT": "decrypt",
+    "DH_PRIME_4096_BIT_GROUP_16": DH_PRIME_4096_BIT_GROUP_16,
+    "DH_GENERATOR_4096_BIT_GROUP_16": DH_GENERATOR_4096_BIT_GROUP_16,
     "DIRECTORY": "directory",
     "ENCRYPT": "encrypt",
     "FAILED": "failed",
@@ -251,34 +253,48 @@ __extras = {
     "ID": "contact_identifier",
     "INACTIVE": "terminated_connection",
     "KEEP_ALIVE": "keep_alive",
-    "KEY": "shared_key",
+    "KEY": "key",
+    "KEY_ID": "key_id",
+    "KEYED_PASSWORD": "keyed_password",
     "LISTENING": "listening",
     "MAINTAINING": "maintaining",
     "MESSAGE_ID": "message_id",
     "MESSAGES": "message_archive",
     "METADATA": "metadata",
+    "Namespace": Namespace,
     "NEW_CONTACT": "new_contact",
+    "NEXT_KEYED_PASSWORD": "next_keyed_password",
+    "NEXT_SALT": "next_salt",
     "NONE": NONE,
     "NUM": NUM,
-    "Namespace": Namespace,
     "OLD_KEY": "last_shared_key",
     "OLD_VERIFID": "last_verification_code",
     "ONION": "onion",
     "ONION_CHAR_TABLE": ONION_CHAR_TABLE,
+    "PASSWORD": "password",
+    "PASSWORD_SALT": "password_salt",
     "PHASE": "phase",
     "PLAINTEXT": "plaintext",
+    "PUB": "pub",
     "PORT": 8081,
     "RACHET": "rachet_shared_key",
     "RECEIVING": "receiving",
+    "REGISTRATION": "registration",
     "RETRY": "retry",
     "SALT": "salt",
-    "SEED": "shared_seed",
+    "SECRET": "secret",
+    "SEED": "seed",
     "SENDER": "sender",
     "SENDING": "sending",
     "SERVER": "server",
     "SERVER_BASE": "server_prime_base",
     "SERVER_PUB": "server_public_key_part",
     "SERVER_SECRET": "server_secret",
+    "SESSION_KEY": "session_key",
+    "SESSION_SALT": "session_salt",
+    "SHARED_KEY": "shared_key",
+    "SHARED_SECRET": "shared_secret",
+    "SHARED_SEED": "shared_seed",
     "STATUS": "status",
     "SUCCESS": "success",
     "TB_PORT": 9150,
@@ -288,6 +304,7 @@ __extras = {
     "USER_MOD": "user_prime_modulus",
     "USER_PUB": "user_public_key_part",
     "USER_SECRET": "user_secret",
+    "VERIFICATION": "verification",
     "VERIFID": "verification_code",
     "WORD_LIST": WORD_LIST,
     "__doc__": __doc__,
@@ -297,6 +314,8 @@ __extras = {
     "create_namespace": create_namespace,
     "aimport_namespace": aimport_namespace,
     "import_namespace": import_namespace,
+    "amake_module": amake_module,
+    "make_module": make_module,
     "bits": bits,
     "power10": power10,
     "primes": primes,
